@@ -1,3 +1,3 @@
 __author__ = 'Milinda Pathirage'
 
-from . import *
\ No newline at end of file
+__all__ = ["dataapi"]
\ No newline at end of file
